@@ -28,8 +28,6 @@
 #' @export custom
 
 
-
-
 custom <- function(FUN = mean, attribute, units = "", color_scale = "PuBu", color_edges = "dodgerblue4") {
   attr(FUN, "attribute") <- attribute
   attr(FUN, "units") <- units
@@ -55,12 +53,14 @@ custom <- function(FUN = mean, attribute, units = "", color_scale = "PuBu", colo
   		na.omit() %>%
   		ungroup() %>%
   		mutate(color_level = label,
+  		       value = label,
   			   shape = if_end(ACTIVITY_CLASSIFIER_,"circle","rectangle"),
   			   fontcolor = if_end(ACTIVITY_CLASSIFIER_, if_start(ACTIVITY_CLASSIFIER_, "chartreuse4","brown4"),  ifelse(label <= (min(label) + (5/8)*diff(range(label))), "black","white")),
   			   color = if_end(ACTIVITY_CLASSIFIER_, if_start(ACTIVITY_CLASSIFIER_, "chartreuse4","brown4"),"grey"),
   			   tooltip =  paste0(ACTIVITY_CLASSIFIER_, "\n", round(label, 2), " ",attr(type, "units")),
   			   label = paste0(ACTIVITY_CLASSIFIER_, "\n", round(label, 2), " ",attr(type, "units")),
-  			   label = if_end(ACTIVITY_CLASSIFIER_, ACTIVITY_CLASSIFIER_, tooltip))
+  			   label = if_end(ACTIVITY_CLASSIFIER_, recode(ACTIVITY_CLASSIFIER_, ARTIFICIAL_START = "Start",ARTIFICIAL_END = "End"),
+  			                  tooltip))
   }
 
   attr(FUN, "create_edges") <- 	function(precedence, type, extra_data) {
@@ -77,12 +77,12 @@ custom <- function(FUN = mean, attribute, units = "", color_scale = "PuBu", colo
   	label_numeric <- NULL
   	consequent <- NULL
 
-
   	precedence %>%
   		ungroup() %>%
   		group_by(ACTIVITY_CLASSIFIER_, next_act, from_id, to_id) %>%
   		summarize(value = type(!!attribute, na.rm = T),
-  				  label = round(type(!!attribute, na.rm = T),2)) %>%
+  		          n = as.double(n()),
+  				      label = round(type(!!attribute, na.rm = T),2)) %>%
   		na.omit() %>%
   		ungroup() %>%
   		mutate(penwidth = rescale(value, to = c(1,5))) %>%
